import { isLofter } from 'nw-detect';
import { callHandler, support } from 'nejsbridge/dist/bridge.lofter.es';

export interface Params {
  inside: boolean,
  opacity?: boolean,
}

const openWithLocation = (url: string) => {
  if (url && url.trim()) {
    window.location.href = url;
  } else {
    console.warn('Url must be provided');
  }
};

const openWithWebview = (url: string, params: Params = {
  inside: true
}) => {
  if (url && url.trim()) {
    if (!isLofter()) {
      openWithLocation(url);
      return;
    }
    window.location.href = `lofter://webview?url=${encodeURIComponent(
      url
    )}&inside=${params.inside}${params.opacity ? `&opacity=${params.opacity}` : ''}}`;
  } else {
    console.warn('Url must be provided');
  }
};

const close = () => {
  callHandler('njb_closeCurrentWebview');
};

// 页面跳转
const go = (url: string, maxCount = 10) => {
  if (!url || !url.trim()) {
    console.warn('Url must be provided');
    return;
  }
  if (isLofter()) {
    if (support('njb_getWebviewCount')) {
      callHandler('njb_getWebviewCount', (data?: { count: number }) => {
        if (data && data.count >= maxCount) {
          openWithLocation(url);
        } else {
          openWithWebview(url);
        }
      });
    } else {
      openWithLocation(url);
    }
  } else {
    openWithLocation(url);
  }
};

export { go, close, openWithLocation, openWithWebview };
